@@ -6,7 +6,7 @@ use parent qw(Perinci::CmdLine::I18N Perinci::To::Text::I18N::fr);
 use Locale::Maketext::Lexicon::Gettext;
 our %Lexicon = %{ Locale::Maketext::Lexicon::Gettext->parse(<DATA>) };
 
-our $VERSION = '0.95'; # VERSION
+our $VERSION = '0.96'; # VERSION
 
 #use Data::Dump; dd \%Lexicon;
 
@@ -15,7 +15,7 @@ our $VERSION = '0.95'; # VERSION
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -23,14 +23,7 @@ Perinci::CmdLine::I18N::fr - French translation for Perinci::CmdLine
 
 =head1 VERSION
 
-version 0.95
-
-=head1 DESCRIPTION
-
-=head1 FUNCTIONS
-
-
-None are exported by default, but they are exportable.
+version 0.96
 
 =head1 HOMEPAGE
 
@@ -42,8 +35,7 @@ Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-CmdLine>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-CmdLine>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
